==> quantlib_1.25.orig.tar.gz: QuantLib-1.25/test-suite/integrals.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2003 RiskMap srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_test_integrals_hpp
#define quantlib_test_integrals_hpp

#include <boost/test/unit_test.hpp>

/* remember to document new and/or updated tests in the Doxygen
   comment block of the corresponding class */

class IntegralTest {
  public:
    static void testSegment();
    static void testTrapezoid();
    static void testMidPointTrapezoid();
    static void testSimpson();
    static void testGaussKronrodAdaptive();
    static void testGaussKronrodNonAdaptive();
    static void testGaussLobatto();
    static void testTwoDimensionalIntegration();
    static void testFolinIntegration();
    static void testDiscreteIntegrals();
    static void testDiscreteIntegrator();
    static void testPiecewiseIntegral();
    static void testRealSiCiIntegrals();
    static void testExponentialIntegral();
    static boost::unit_test_framework::test_suite* suite();
};


#endif

==> quantlib_1.29.orig.tar.gz: QuantLib-1.29/test-suite/integrals.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2003 RiskMap srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/license.shtml>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_test_integrals_hpp
#define quantlib_test_integrals_hpp

#include <boost/test/unit_test.hpp>

/* remember to document new and/or updated tests in the Doxygen
   comment block of the corresponding class */

class IntegralTest {
  public:
    static void testSegment();
    static void testTrapezoid();
    static void testMidPointTrapezoid();
    static void testSimpson();
    static void testGaussKronrodAdaptive();
    static void testGaussKronrodNonAdaptive();
    static void testGaussLobatto();
    static void testTanhSinh();
    static void testGaussLegendreIntegrator();
    static void testGaussChebyshevIntegrator();
    static void testGaussChebyshev2ndIntegrator();
    static void testTwoDimensionalIntegration();
    static void testFolinIntegration();
    static void testDiscreteIntegrals();
    static void testDiscreteIntegrator();
    static void testPiecewiseIntegral();
    static void testRealSiCiIntegrals();
    static void testExponentialIntegral();
    static boost::unit_test_framework::test_suite* suite();
};


#endif
